<?php


if (class_exists('backup_component2')) {
	class backup_amiserv5 extends backup_component2
	  {
		public function name()
		{
		  return 'amiserv5';
		}

		public function optional()
		{
		  return false;
		}

		public function requires() {
			return [ 'cpbx5' ];
		}


		public function backup()
		{
		  $this->backup_database('amiserv5');

		  
		  if (file_exists($dirname = "/etc/amiserv5")) {
			$this->backup_folder($dirname);
		  }
		  if (file_exists($dirname = "/etc/httpd/conf.d/z_amiserv.conf")) {
			$this->backup_file($dirname);
		  }
		  if (file_exists($dirname = "/etc/apache2/conf-available/z_amiserv.conf")) {
			$this->backup_file($dirname);
		  }
		  if (file_exists($dirname = "/etc/ipconnect/amiserv5.ver")) {
			$this->backup_file($dirname);
		  }
		}

		public function pre_restore()
		{
		  $this->drop_database('amiserv5');
		}

		public function restore()
		{
		  $this->restore_database('amiserv5');
		  $this->restore_folder('/etc/amiserv5');
		  $this->restore_file('/etc/httpd/conf.d/z_amiserv.conf');
		  $this->restore_file('/etc/apache2/conf-available/z_amiserv.conf');
		  $this->restore_file('/etc/ipconnect/amiserv5.ver');
		}

		public function post_restore()
		{
		  $this->exec('bash /usr/share/amiserv5/InstallScripts/after_update.sh');
		  if (file_exists("/etc/amiserv5/appkey")) {
			  //remove old appkey, it will be regenerated
			  unlink("/etc/amiserv5/appkey");
		  }
		  $this->exec('systemctl restart amiserv5');
		}
	  }
}
else {
	class backup_amiserv5 extends backup_component {
		public function name() {
			return 'amiserv5';
		}

		public function optional() {
			return false;
		}

		public function requires() {
			return [ 'cpbx5' ];
		}

		public function backup($tmpdir) {
			$archives = [];
		
			$this->backup_database(
				'amiserv5',
				$archives[] = "{$tmpdir}/amiserv5.sql.gz"
			);

			if (file_exists($dirname = "/etc/amiserv5")) {
				$this->backup_folder($dirname, $archive = "{$tmpdir}/amiserv5.tar.gz");
				$archives[] = $archive;
			}
		
			if (file_exists($dirname = "/etc/ipconnect/amiserv5.ver")) {
				$archive = "{$tmpdir}/ipconn_amiserv.tar.gz";
				static::exec(
					"tar czPf {$archive} -C /etc/ipconnect amiserv5.ver --acls --ignore-failed-read "
				);
				$archives[] = $archive;
			}
			return $archives;
		}

		public function pre_restore($tmpdir) {
			if (file_exists("{$tmpdir}/amiserv5.sql.gz")) {
				$this->drop_database('amiserv5');
			}
		}

		public function restore($tmpdir) {
			if (file_exists($archive = "{$tmpdir}/amiserv5.sql.gz")) {
				$this->restore_database($archive, 'amiserv5');
			}

			if (file_exists($archive = "{$tmpdir}/amiserv5.tar.gz")) {
				$this->restore_folder($archive, '/etc/amiserv5');
			}
		
			if (file_exists($archive = "{$tmpdir}/ipconn_amiserv.tar.gz")) {
				$this->restore_folder($archive, '/etc/ipconnect');
			}
		}

		public function post_restore($tmpdir) {
			if (file_exists('/usr/share/amiserv5/InstallScripts/after_update.sh')) {
				$this->exec('bash /usr/share/amiserv5/InstallScripts/after_update.sh');
			}
			if (file_exists("/etc/amiserv5/appkey")) {
			  //remove old appkey, it will be regenerated
			  unlink("/etc/amiserv5/appkey");
		  }
		  $this->exec('systemctl restart amiserv5');
		}
	}
}


?>
